datablock WheeledVehicleSpring(ScramjetSpring)
{
   // Wheel suspension properties
   length = 0.1;			 // Suspension travel
   force = 6000; //3000;		 // Spring force
   damping = 400; //600;		 // Spring damping
   antiSwayForce = 3; //3;		 // Lateral anti-sway force
};

///////////////////////////////////////////////////////////////

datablock WheeledVehicleTire(ScramjetTire)
{
   // Tires act as springs and generate lateral and longitudinal
   // forces to move the vehicle. These distortion/spring forces
   // are what convert wheel angular velocity into forces that
   // act on the rigid body.
   shapeFile = "./Scramjetwheel.dts";
	
	mass = 10;
    radius = 1;
    staticFriction = 5;
   kineticFriction = 5;
   restitution = 0.5;	

   // Spring that generates lateral tire forces
   lateralForce = 18000;
   lateralDamping = 4000;
   lateralRelaxation = 0.01;

   // Spring that generates longitudinal tire forces
   longitudinalForce = 14000;
   longitudinalDamping = 2000;
   longitudinalRelaxation = 0.01;
};

////////////////////////////////////////////////

datablock AudioProfile(ScramjetSound)
{
   filename    = "./carrier_0.wav";
   description = AudioClose3d;
   preload = true;
};
datablock AudioProfile(Scramjet2Sound)
{
   filename    = "./carrier_1.wav";
   description = AudioClose3d;
   preload = true;
};



datablock WheeledVehicleData(ScramjetVehicle)
{
	category = "Vehicles";
	displayName = " ";
	shapeFile = "./jetplane3.dts"; 
	emap = true;
	minMountDist = 3;
   
   numMountPoints = 7;
   mountThread[0] = "sit";
   mountThread[1] = "sit";
   mountThread[2] = "sit";
   mountThread[3] = "sit";
   mountThread[4] = "sit";
   mountThread[5] = "sit";
   mountThread[6] = "sit";
   mountThread[7] = "sit";

	maxDamage = 260.00;
	destroyedLevel = 260.00;
	energyPerDamagePoint = 160;
	speedDamageScale = 1.04;
	collDamageThresholdVel = 20.0;
	collDamageMultiplier   = 0.02;

	massCenter = "0 0 0";
   //massBox = "2 5 1";

	maxSteeringAngle = 0.9785;  // Maximum steering angle, should match animation
	integration = 4;           // Force integration time: TickSec/Rate
	tireEmitter = VehicleTireEmitter; // All the tires use the same dust emitter

	// 3rd person camera settings
	cameraRoll = false;         // Roll the camera with the vehicle
	cameraMaxDist = 14;         // Far distance from vehicle
	cameraOffset = 8.1;        // Vertical offset from camera mount point
	cameraLag = 0.0;           // Velocity lag of camera
	cameraDecay = 0.75;        // Decay per sec. rate of velocity lag
	cameraTilt = 0.4;
   collisionTol = 0.1;        // Collision distance tolerance
   contactTol = 0.1;

	useEyePoint = false;	

	defaultTire	  = ScramjetTire;
	defaultSpring = ScramjetSpring;
//	flatTire	     = jeepFlatTire;
//	flatSpring	  = jeepFlatSpring;

   numWheels = 3;

	// Rigid Body
	mass = 200;
	density = 5.0;
	drag = 0.4;
	bodyFriction = 0.6;
	bodyRestitution = 0.6;
	minImpactSpeed = 10;        // Impacts over this invoke the script callback
	softImpactSpeed = 10;       // Play SoftImpact Sound
	hardImpactSpeed = 15;      // Play HardImpact Sound
	groundImpactMinSpeed    = 10.0;

	// Engine
	engineTorque = 12000; //4000;       // Engine power
	engineBrake = 2000;         // Braking when throttle is 0
	brakeTorque = 4000;        // When brakes are applied
	maxWheelSpeed = 20;        // Engine scale by current speed / max speed

	rollForce		= 900;
	yawForce		= 600;
	pitchForce		= 1000;
	rotationalDrag		= 0.2;

	// Energy
	maxEnergy = 100;
	jetForce = 3000;
	minJetEnergy = 30;
	jetEnergyDrain = 2;

   isSled = false;

   forwardThrust		= 6000;
	reverseThrust		= 5000;
	lift			= 100;
	maxForwardVel		= 80;
	maxReverseVel		= 50;
	horizontalSurfaceForce	= 130;   // Horizontal center "wing" (provides "bite" into the wind for climbing/diving and turning)
	verticalSurfaceForce	= 130; 
	rollForce		= 6000;
	yawForce		= 8000;
	pitchForce		= 8000;
	rotationalDrag		= 0.4;
	stallSpeed		= 10;

//   forwardThrust		= 2000;
//	reverseThrust		= 2000;
//	lift			= 100;
//	maxForwardVel		= 70;
//	maxReverseVel		= 70;
//	horizontalSurfaceForce	= 100;   // Horizontal center "wing" (provides "bite" into the wind for climbing/diving and turning)
//	verticalSurfaceForce	= 100; 
//	rollForce		= 6000;
//	yawForce		= 6000;
//	pitchForce		= 4000;
//	rotationalDrag		= 0.5;
//	stallSpeed		= 10;
//
//   forwardThrust		= 2500;
//	reverseThrust		= 500;
//	lift			= 15000;
//	maxForwardVel		= 60;
//	maxReverseVel		= 10;
//	horizontalSurfaceForce	= 500;   // Horizontal center "wing" (provides "bite" into the wind for climbing/diving and turning)
//	verticalSurfaceForce	= 500; 
//	rollForce		= 5000;
//	yawForce		= 5000;
//	pitchForce		= 5000;
//	rotationalDrag		= 0.1;
//	stallSpeed		= 10;

	splash = vehicleSplash;
	splashVelocity = 4.0;
	splashAngle = 67.0;
	splashFreqMod = 300.0;
	splashVelEpsilon = 0.60;
	bubbleEmitTime = 1.4;
	splashEmitter[0] = vehicleFoamDropletsEmitter;
	splashEmitter[1] = vehicleFoamEmitter;
	splashEmitter[2] = vehicleBubbleEmitter;
	mediumSplashSoundVelocity = 10.0;   
	hardSplashSoundVelocity = 20.0;   
	exitSplashSoundVelocity = 5.0;
		
	//mediumSplashSound = "";
	//hardSplashSound = "";
	//exitSplashSound = "";
	
	// Sounds
	//   jetSound = ScoutThrustSound;
	//engineSound = idleSound;
	//squealSound = skidSound;
	softImpactSound = ScramjetSound;
	hardImpactSound = Scramjet2Sound;
	//wheelImpactSound = slowImpactSound;

	//   explosion = VehicleExplosion;
	justcollided = 0;

   uiName = "Scramjet ";
	rideable = true;
		lookUpLimit = 0.65;
		lookDownLimit = 0.45;

	paintable = true;
   
   damageEmitter[0] = VehicleBurnEmitter;
	damageEmitterOffset[0] = "0.0 0.0 0.0 ";
	damageLevelTolerance[0] = 0.99;

   damageEmitter[1] = VehicleBurnEmitter;
	damageEmitterOffset[1] = "0.0 0.0 0.0 ";
	damageLevelTolerance[1] = 1.0;

   numDmgEmitterAreas = 1;

   initialExplosionProjectile = vehicleExplosionProjectile;
   initialExplosionOffset = 0;         //offset only uses a z value for now

   burnTime = 13000;
   minJetEngineSpeed = 20;

   finalExplosionProjectile = vehicleFinalExplosionProjectile;
   finalExplosionOffset = 0.5;          //offset only uses a z value for now


   minRunOverSpeed    = 4;   //how fast you need to be going to run someone over (do damage)
   runOverDamageScale = 19;   //when you run over someone, speed * runoverdamagescale = damage amt
   runOverPushScale   = 4.2; //how hard a person you're running over gets pushed

   steeringUseStrafeSteering = false; //this vehicle has pitch control, so we can't use strafe steering
};

//jet, you fool! JET!

datablock ParticleData(ScramjetEngineSmokeParticle)
{
	dragCoefficient      = 0;
	gravityCoefficient   = -0.1;
	inheritedVelFactor   = 0.0;
	constantAcceleration = 0.0;
	lifetimeMS           = 3000;
	lifetimeVarianceMS   = 150;
	textureName          = "base/data/particles/cloud";
	spinSpeed		= 2.0;
	spinRandomMin		= -500.0;
	spinRandomMax		= 500.0;
	colors[0]     = "0.3 0.3 0.3 0.4";
	colors[1]     = "0.5 0.5 0.5 0.2";
	colors[2]     = "0.0 0.0 0.0 0.0";
	sizes[0]      = 0.75;
	sizes[1]      = 5.0;
	sizes[2]      = 6.0;
	times[0]		= 0;
	times[1]		= 0.1;
	times[2]		= 1;

	useInvAlpha = false;
};
datablock ParticleEmitterData(ScramjetEngineSmokeEmitter)
{
   ejectionPeriodMS = 20;
   periodVarianceMS = 5;
   ejectionVelocity = 0.0;
   velocityVariance = 0.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 0;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "ScramjetEngineSmokeParticle";
   
   //uiName = "Mini Jet Engine Smoke Emitter";
};

datablock ShapeBaseImageData(ScramjetEngineImage3)
{
   shapeFile = "./empty.dts";
	emap = false;

	mountPoint = 7;
   rotation = "1 0 0 180";

	stateName[0]					= "Ready";
	stateTransitionOnTimeout[0]		= "FireA";
	stateTimeoutValue[0]			= 0.01;

	stateName[1]					= "FireA";
	stateTransitionOnTimeout[1]		= "Done";
	stateWaitForTimeout[1]			= True;
	stateTimeoutValue[1]			= 10000;
	stateEmitter[1]					= ScramjetEngineSmokeEmitter;
	stateEmitterTime[1]				= 10000;

	stateName[2]					= "Done";
	stateScript[2]					= "onDone";
};
function ScramjetEngineImage3::onDone(%this,%obj,%slot)
{
	%obj.unMountImage(%slot);
}

datablock ShapeBaseImageData(ScramjetEngineImage4)
{
   shapeFile = "./empty.dts";
	emap = false;

	mountPoint = 8;
   rotation = "1 0 0 180";

	stateName[0]					= "Ready";
	stateTransitionOnTimeout[0]		= "FireA";
	stateTimeoutValue[0]			= 0.01;

	stateName[1]					= "FireA";
	stateTransitionOnTimeout[1]		= "Done";
	stateWaitForTimeout[1]			= True;
	stateTimeoutValue[1]			= 10000;
	stateEmitter[1]					= ScramjetEngineSmokeEmitter;
	stateEmitterTime[1]				= 10000;

	stateName[2]					= "Done";
	stateScript[2]					= "onDone";
};

function ScramjetEngineImage4::onDone(%this,%obj,%slot)
{
	%obj.unMountImage(%slot);
}


//the actual cody tidbits, starting with the onAdd

function Scramjetvehicle::onadd(%this,%obj)
{ 
	parent::onadd(%this,%obj);
		
	%obj.setWheelTire(0, Scramjettire);
	%obj.setWheelTire(1, Scramjettire);
	%obj.setWheelTire(2, Scramjettire);

	%obj.setWheelSpring(0, ScramjetSpring);
	%obj.setWheelSpring(1, ScramjetSpring);
	%obj.setWheelSpring(2, ScramjetSpring);
	
	%obj.setWheelSteering(0,0);
	%obj.setWheelSteering(1,0);
	%obj.setWheelSteering(2,-1);

	%obj.setWheelPowered(0,true);
    %obj.setWheelPowered(1,true);
	%obj.setWheelPowered(2,true);
	    
	ScramjetEngineCheck(%obj);

	%obj.playThread(0,spinslow);
	%obj.prop = "slow";
}


function ScramjetEngineCheck(%obj)
{
//	return;
	if(!isObject(%obj))
		return;

	%speed = vectorLen(%obj.getVelocity());
	if(%speed < %obj.dataBlock.minJetEngineSpeed)
	{
		if(%obj.getMountedImage(1) !$= "")
		{
			%obj.unMountImage(2);
			%obj.unMountImage(3);
		}
	}
	else
	{
		if(%obj.getMountedImage(1) $= 0)
		{
			%obj.mountImage(ScramjetEngineImage3,2);
			%obj.mountImage(ScramjetEngineImage4,3);
		}
	}

/////////////////////////////////////////////////////////////////////

	if(%speed < 20)
	{
		if(%obj.prop !$= "slow")
		{
			%obj.playThread(0,spinslow);
			%obj.prop = "slow";
		}
	}
	else
	{
		if(%obj.prop !$= "fast")
		{
			%obj.playThread(0,spinfast);
			%obj.prop = "fast";
		}
	}


	schedule(2000,0,"ScramjetEngineCheck",%obj);
}


